"""
Type annotations for notifications service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/type_defs/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from types_boto3_notifications.type_defs import SummarizationDimensionDetailTypeDef

    data: SummarizationDimensionDetailTypeDef = ...
    ```
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Union

from .literals import (
    AccessStatusType,
    AccountContactTypeType,
    AggregationDurationType,
    AggregationEventTypeType,
    ChannelAssociationOverrideOptionType,
    ChannelTypeType,
    EventRuleStatusType,
    EventStatusType,
    LocaleCodeType,
    NotificationConfigurationStatusType,
    NotificationHubStatusType,
    NotificationTypeType,
    TextPartTypeType,
)

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import list as List
    from collections.abc import Mapping, Sequence
else:
    from typing import Dict, List, Mapping, Sequence
if sys.version_info >= (3, 12):
    from typing import Literal, NotRequired, TypedDict
else:
    from typing_extensions import Literal, NotRequired, TypedDict


__all__ = (
    "AggregationDetailTypeDef",
    "AggregationKeyTypeDef",
    "AggregationSummaryTypeDef",
    "AssociateChannelRequestTypeDef",
    "AssociateManagedNotificationAccountContactRequestTypeDef",
    "AssociateManagedNotificationAdditionalChannelRequestTypeDef",
    "CreateEventRuleRequestTypeDef",
    "CreateEventRuleResponseTypeDef",
    "CreateNotificationConfigurationRequestTypeDef",
    "CreateNotificationConfigurationResponseTypeDef",
    "DeleteEventRuleRequestTypeDef",
    "DeleteNotificationConfigurationRequestTypeDef",
    "DeregisterNotificationHubRequestTypeDef",
    "DeregisterNotificationHubResponseTypeDef",
    "DimensionTypeDef",
    "DisassociateChannelRequestTypeDef",
    "DisassociateManagedNotificationAccountContactRequestTypeDef",
    "DisassociateManagedNotificationAdditionalChannelRequestTypeDef",
    "EventRuleStatusSummaryTypeDef",
    "EventRuleStructureTypeDef",
    "GetEventRuleRequestTypeDef",
    "GetEventRuleResponseTypeDef",
    "GetManagedNotificationChildEventRequestTypeDef",
    "GetManagedNotificationChildEventResponseTypeDef",
    "GetManagedNotificationConfigurationRequestTypeDef",
    "GetManagedNotificationConfigurationResponseTypeDef",
    "GetManagedNotificationEventRequestTypeDef",
    "GetManagedNotificationEventResponseTypeDef",
    "GetNotificationConfigurationRequestTypeDef",
    "GetNotificationConfigurationResponseTypeDef",
    "GetNotificationEventRequestTypeDef",
    "GetNotificationEventResponseTypeDef",
    "GetNotificationsAccessForOrganizationResponseTypeDef",
    "ListChannelsRequestPaginateTypeDef",
    "ListChannelsRequestTypeDef",
    "ListChannelsResponseTypeDef",
    "ListEventRulesRequestPaginateTypeDef",
    "ListEventRulesRequestTypeDef",
    "ListEventRulesResponseTypeDef",
    "ListManagedNotificationChannelAssociationsRequestPaginateTypeDef",
    "ListManagedNotificationChannelAssociationsRequestTypeDef",
    "ListManagedNotificationChannelAssociationsResponseTypeDef",
    "ListManagedNotificationChildEventsRequestPaginateTypeDef",
    "ListManagedNotificationChildEventsRequestTypeDef",
    "ListManagedNotificationChildEventsResponseTypeDef",
    "ListManagedNotificationConfigurationsRequestPaginateTypeDef",
    "ListManagedNotificationConfigurationsRequestTypeDef",
    "ListManagedNotificationConfigurationsResponseTypeDef",
    "ListManagedNotificationEventsRequestPaginateTypeDef",
    "ListManagedNotificationEventsRequestTypeDef",
    "ListManagedNotificationEventsResponseTypeDef",
    "ListNotificationConfigurationsRequestPaginateTypeDef",
    "ListNotificationConfigurationsRequestTypeDef",
    "ListNotificationConfigurationsResponseTypeDef",
    "ListNotificationEventsRequestPaginateTypeDef",
    "ListNotificationEventsRequestTypeDef",
    "ListNotificationEventsResponseTypeDef",
    "ListNotificationHubsRequestPaginateTypeDef",
    "ListNotificationHubsRequestTypeDef",
    "ListNotificationHubsResponseTypeDef",
    "ListTagsForResourceRequestTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "ManagedNotificationChannelAssociationSummaryTypeDef",
    "ManagedNotificationChildEventOverviewTypeDef",
    "ManagedNotificationChildEventSummaryTypeDef",
    "ManagedNotificationChildEventTypeDef",
    "ManagedNotificationConfigurationStructureTypeDef",
    "ManagedNotificationEventOverviewTypeDef",
    "ManagedNotificationEventSummaryTypeDef",
    "ManagedNotificationEventTypeDef",
    "ManagedSourceEventMetadataSummaryTypeDef",
    "MediaElementTypeDef",
    "MessageComponentsSummaryTypeDef",
    "MessageComponentsTypeDef",
    "NotificationConfigurationStructureTypeDef",
    "NotificationEventOverviewTypeDef",
    "NotificationEventSummaryTypeDef",
    "NotificationEventTypeDef",
    "NotificationHubOverviewTypeDef",
    "NotificationHubStatusSummaryTypeDef",
    "NotificationsAccessForOrganizationTypeDef",
    "PaginatorConfigTypeDef",
    "RegisterNotificationHubRequestTypeDef",
    "RegisterNotificationHubResponseTypeDef",
    "ResourceTypeDef",
    "ResponseMetadataTypeDef",
    "SourceEventMetadataSummaryTypeDef",
    "SourceEventMetadataTypeDef",
    "SummarizationDimensionDetailTypeDef",
    "SummarizationDimensionOverviewTypeDef",
    "TagResourceRequestTypeDef",
    "TextPartValueTypeDef",
    "TimestampTypeDef",
    "UntagResourceRequestTypeDef",
    "UpdateEventRuleRequestTypeDef",
    "UpdateEventRuleResponseTypeDef",
    "UpdateNotificationConfigurationRequestTypeDef",
    "UpdateNotificationConfigurationResponseTypeDef",
)


class SummarizationDimensionDetailTypeDef(TypedDict):
    name: str
    value: str


class AggregationKeyTypeDef(TypedDict):
    name: str
    value: str


class SummarizationDimensionOverviewTypeDef(TypedDict):
    name: str
    count: int
    sampleValues: NotRequired[List[str]]


class AssociateChannelRequestTypeDef(TypedDict):
    arn: str
    notificationConfigurationArn: str


class AssociateManagedNotificationAccountContactRequestTypeDef(TypedDict):
    contactIdentifier: AccountContactTypeType
    managedNotificationConfigurationArn: str


class AssociateManagedNotificationAdditionalChannelRequestTypeDef(TypedDict):
    channelArn: str
    managedNotificationConfigurationArn: str


class CreateEventRuleRequestTypeDef(TypedDict):
    notificationConfigurationArn: str
    source: str
    eventType: str
    regions: Sequence[str]
    eventPattern: NotRequired[str]


class EventRuleStatusSummaryTypeDef(TypedDict):
    status: EventRuleStatusType
    reason: str


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: Dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class CreateNotificationConfigurationRequestTypeDef(TypedDict):
    name: str
    description: str
    aggregationDuration: NotRequired[AggregationDurationType]
    tags: NotRequired[Mapping[str, str]]


class DeleteEventRuleRequestTypeDef(TypedDict):
    arn: str


class DeleteNotificationConfigurationRequestTypeDef(TypedDict):
    arn: str


class DeregisterNotificationHubRequestTypeDef(TypedDict):
    notificationHubRegion: str


class NotificationHubStatusSummaryTypeDef(TypedDict):
    status: NotificationHubStatusType
    reason: str


class DimensionTypeDef(TypedDict):
    name: str
    value: str


class DisassociateChannelRequestTypeDef(TypedDict):
    arn: str
    notificationConfigurationArn: str


class DisassociateManagedNotificationAccountContactRequestTypeDef(TypedDict):
    contactIdentifier: AccountContactTypeType
    managedNotificationConfigurationArn: str


class DisassociateManagedNotificationAdditionalChannelRequestTypeDef(TypedDict):
    channelArn: str
    managedNotificationConfigurationArn: str


class GetEventRuleRequestTypeDef(TypedDict):
    arn: str


class GetManagedNotificationChildEventRequestTypeDef(TypedDict):
    arn: str
    locale: NotRequired[LocaleCodeType]


class GetManagedNotificationConfigurationRequestTypeDef(TypedDict):
    arn: str


class GetManagedNotificationEventRequestTypeDef(TypedDict):
    arn: str
    locale: NotRequired[LocaleCodeType]


class GetNotificationConfigurationRequestTypeDef(TypedDict):
    arn: str


class GetNotificationEventRequestTypeDef(TypedDict):
    arn: str
    locale: NotRequired[LocaleCodeType]


class NotificationsAccessForOrganizationTypeDef(TypedDict):
    accessStatus: AccessStatusType


class PaginatorConfigTypeDef(TypedDict):
    MaxItems: NotRequired[int]
    PageSize: NotRequired[int]
    StartingToken: NotRequired[str]


class ListChannelsRequestTypeDef(TypedDict):
    notificationConfigurationArn: str
    maxResults: NotRequired[int]
    nextToken: NotRequired[str]


class ListEventRulesRequestTypeDef(TypedDict):
    notificationConfigurationArn: str
    maxResults: NotRequired[int]
    nextToken: NotRequired[str]


class ListManagedNotificationChannelAssociationsRequestTypeDef(TypedDict):
    managedNotificationConfigurationArn: str
    maxResults: NotRequired[int]
    nextToken: NotRequired[str]


class ManagedNotificationChannelAssociationSummaryTypeDef(TypedDict):
    channelIdentifier: str
    channelType: ChannelTypeType
    overrideOption: NotRequired[ChannelAssociationOverrideOptionType]


TimestampTypeDef = Union[datetime, str]


class ListManagedNotificationConfigurationsRequestTypeDef(TypedDict):
    channelIdentifier: NotRequired[str]
    maxResults: NotRequired[int]
    nextToken: NotRequired[str]


class ManagedNotificationConfigurationStructureTypeDef(TypedDict):
    arn: str
    name: str
    description: str


class ListNotificationConfigurationsRequestTypeDef(TypedDict):
    eventRuleSource: NotRequired[str]
    channelArn: NotRequired[str]
    status: NotRequired[NotificationConfigurationStatusType]
    maxResults: NotRequired[int]
    nextToken: NotRequired[str]


class NotificationConfigurationStructureTypeDef(TypedDict):
    arn: str
    name: str
    description: str
    status: NotificationConfigurationStatusType
    creationTime: datetime
    aggregationDuration: NotRequired[AggregationDurationType]


class ListNotificationHubsRequestTypeDef(TypedDict):
    maxResults: NotRequired[int]
    nextToken: NotRequired[str]


class ListTagsForResourceRequestTypeDef(TypedDict):
    arn: str


class ManagedSourceEventMetadataSummaryTypeDef(TypedDict):
    source: str
    eventType: str
    eventOriginRegion: NotRequired[str]


class MessageComponentsSummaryTypeDef(TypedDict):
    headline: str


TextPartValueTypeDef = TypedDict(
    "TextPartValueTypeDef",
    {
        "type": TextPartTypeType,
        "displayText": NotRequired[str],
        "textByLocale": NotRequired[Dict[LocaleCodeType, str]],
        "url": NotRequired[str],
    },
)
MediaElementTypeDef = TypedDict(
    "MediaElementTypeDef",
    {
        "mediaId": str,
        "type": Literal["IMAGE"],
        "url": str,
        "caption": str,
    },
)


class SourceEventMetadataSummaryTypeDef(TypedDict):
    source: str
    eventType: str
    eventOriginRegion: NotRequired[str]


class RegisterNotificationHubRequestTypeDef(TypedDict):
    notificationHubRegion: str


ResourceTypeDef = TypedDict(
    "ResourceTypeDef",
    {
        "id": NotRequired[str],
        "arn": NotRequired[str],
        "detailUrl": NotRequired[str],
        "tags": NotRequired[List[str]],
    },
)


class TagResourceRequestTypeDef(TypedDict):
    arn: str
    tags: Mapping[str, str]


class UntagResourceRequestTypeDef(TypedDict):
    arn: str
    tagKeys: Sequence[str]


class UpdateEventRuleRequestTypeDef(TypedDict):
    arn: str
    eventPattern: NotRequired[str]
    regions: NotRequired[Sequence[str]]


class UpdateNotificationConfigurationRequestTypeDef(TypedDict):
    arn: str
    name: NotRequired[str]
    description: NotRequired[str]
    aggregationDuration: NotRequired[AggregationDurationType]


class AggregationDetailTypeDef(TypedDict):
    summarizationDimensions: NotRequired[List[SummarizationDimensionDetailTypeDef]]


class AggregationSummaryTypeDef(TypedDict):
    eventCount: int
    aggregatedBy: List[AggregationKeyTypeDef]
    aggregatedAccounts: SummarizationDimensionOverviewTypeDef
    aggregatedRegions: SummarizationDimensionOverviewTypeDef
    aggregatedOrganizationalUnits: NotRequired[SummarizationDimensionOverviewTypeDef]
    additionalSummarizationDimensions: NotRequired[List[SummarizationDimensionOverviewTypeDef]]


class EventRuleStructureTypeDef(TypedDict):
    arn: str
    notificationConfigurationArn: str
    creationTime: datetime
    source: str
    eventType: str
    eventPattern: str
    regions: List[str]
    managedRules: List[str]
    statusSummaryByRegion: Dict[str, EventRuleStatusSummaryTypeDef]


class CreateEventRuleResponseTypeDef(TypedDict):
    arn: str
    notificationConfigurationArn: str
    statusSummaryByRegion: Dict[str, EventRuleStatusSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class CreateNotificationConfigurationResponseTypeDef(TypedDict):
    arn: str
    status: NotificationConfigurationStatusType
    ResponseMetadata: ResponseMetadataTypeDef


class GetEventRuleResponseTypeDef(TypedDict):
    arn: str
    notificationConfigurationArn: str
    creationTime: datetime
    source: str
    eventType: str
    eventPattern: str
    regions: List[str]
    managedRules: List[str]
    statusSummaryByRegion: Dict[str, EventRuleStatusSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class GetManagedNotificationConfigurationResponseTypeDef(TypedDict):
    arn: str
    name: str
    description: str
    category: str
    subCategory: str
    ResponseMetadata: ResponseMetadataTypeDef


class GetNotificationConfigurationResponseTypeDef(TypedDict):
    arn: str
    name: str
    description: str
    status: NotificationConfigurationStatusType
    creationTime: datetime
    aggregationDuration: AggregationDurationType
    ResponseMetadata: ResponseMetadataTypeDef


class ListChannelsResponseTypeDef(TypedDict):
    channels: List[str]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]


class ListTagsForResourceResponseTypeDef(TypedDict):
    tags: Dict[str, str]
    ResponseMetadata: ResponseMetadataTypeDef


class UpdateEventRuleResponseTypeDef(TypedDict):
    arn: str
    notificationConfigurationArn: str
    statusSummaryByRegion: Dict[str, EventRuleStatusSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class UpdateNotificationConfigurationResponseTypeDef(TypedDict):
    arn: str
    ResponseMetadata: ResponseMetadataTypeDef


class DeregisterNotificationHubResponseTypeDef(TypedDict):
    notificationHubRegion: str
    statusSummary: NotificationHubStatusSummaryTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class NotificationHubOverviewTypeDef(TypedDict):
    notificationHubRegion: str
    statusSummary: NotificationHubStatusSummaryTypeDef
    creationTime: datetime
    lastActivationTime: NotRequired[datetime]


class RegisterNotificationHubResponseTypeDef(TypedDict):
    notificationHubRegion: str
    statusSummary: NotificationHubStatusSummaryTypeDef
    creationTime: datetime
    lastActivationTime: datetime
    ResponseMetadata: ResponseMetadataTypeDef


class MessageComponentsTypeDef(TypedDict):
    headline: NotRequired[str]
    paragraphSummary: NotRequired[str]
    completeDescription: NotRequired[str]
    dimensions: NotRequired[List[DimensionTypeDef]]


class GetNotificationsAccessForOrganizationResponseTypeDef(TypedDict):
    notificationsAccessForOrganization: NotificationsAccessForOrganizationTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ListChannelsRequestPaginateTypeDef(TypedDict):
    notificationConfigurationArn: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListEventRulesRequestPaginateTypeDef(TypedDict):
    notificationConfigurationArn: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListManagedNotificationChannelAssociationsRequestPaginateTypeDef(TypedDict):
    managedNotificationConfigurationArn: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListManagedNotificationConfigurationsRequestPaginateTypeDef(TypedDict):
    channelIdentifier: NotRequired[str]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListNotificationConfigurationsRequestPaginateTypeDef(TypedDict):
    eventRuleSource: NotRequired[str]
    channelArn: NotRequired[str]
    status: NotRequired[NotificationConfigurationStatusType]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListNotificationHubsRequestPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListManagedNotificationChannelAssociationsResponseTypeDef(TypedDict):
    channelAssociations: List[ManagedNotificationChannelAssociationSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]


class ListManagedNotificationChildEventsRequestPaginateTypeDef(TypedDict):
    aggregateManagedNotificationEventArn: str
    startTime: NotRequired[TimestampTypeDef]
    endTime: NotRequired[TimestampTypeDef]
    locale: NotRequired[LocaleCodeType]
    relatedAccount: NotRequired[str]
    organizationalUnitId: NotRequired[str]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListManagedNotificationChildEventsRequestTypeDef(TypedDict):
    aggregateManagedNotificationEventArn: str
    startTime: NotRequired[TimestampTypeDef]
    endTime: NotRequired[TimestampTypeDef]
    locale: NotRequired[LocaleCodeType]
    maxResults: NotRequired[int]
    relatedAccount: NotRequired[str]
    organizationalUnitId: NotRequired[str]
    nextToken: NotRequired[str]


class ListManagedNotificationEventsRequestPaginateTypeDef(TypedDict):
    startTime: NotRequired[TimestampTypeDef]
    endTime: NotRequired[TimestampTypeDef]
    locale: NotRequired[LocaleCodeType]
    source: NotRequired[str]
    organizationalUnitId: NotRequired[str]
    relatedAccount: NotRequired[str]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListManagedNotificationEventsRequestTypeDef(TypedDict):
    startTime: NotRequired[TimestampTypeDef]
    endTime: NotRequired[TimestampTypeDef]
    locale: NotRequired[LocaleCodeType]
    source: NotRequired[str]
    maxResults: NotRequired[int]
    nextToken: NotRequired[str]
    organizationalUnitId: NotRequired[str]
    relatedAccount: NotRequired[str]


class ListNotificationEventsRequestPaginateTypeDef(TypedDict):
    startTime: NotRequired[TimestampTypeDef]
    endTime: NotRequired[TimestampTypeDef]
    locale: NotRequired[LocaleCodeType]
    source: NotRequired[str]
    includeChildEvents: NotRequired[bool]
    aggregateNotificationEventArn: NotRequired[str]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListNotificationEventsRequestTypeDef(TypedDict):
    startTime: NotRequired[TimestampTypeDef]
    endTime: NotRequired[TimestampTypeDef]
    locale: NotRequired[LocaleCodeType]
    source: NotRequired[str]
    includeChildEvents: NotRequired[bool]
    aggregateNotificationEventArn: NotRequired[str]
    maxResults: NotRequired[int]
    nextToken: NotRequired[str]


class ListManagedNotificationConfigurationsResponseTypeDef(TypedDict):
    managedNotificationConfigurations: List[ManagedNotificationConfigurationStructureTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]


class ListNotificationConfigurationsResponseTypeDef(TypedDict):
    notificationConfigurations: List[NotificationConfigurationStructureTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]


class ManagedNotificationEventSummaryTypeDef(TypedDict):
    schemaVersion: Literal["v1.0"]
    sourceEventMetadata: ManagedSourceEventMetadataSummaryTypeDef
    messageComponents: MessageComponentsSummaryTypeDef
    eventStatus: EventStatusType
    notificationType: NotificationTypeType


class NotificationEventSummaryTypeDef(TypedDict):
    schemaVersion: Literal["v1.0"]
    sourceEventMetadata: SourceEventMetadataSummaryTypeDef
    messageComponents: MessageComponentsSummaryTypeDef
    eventStatus: EventStatusType
    notificationType: NotificationTypeType


class SourceEventMetadataTypeDef(TypedDict):
    eventTypeVersion: str
    sourceEventId: str
    relatedAccount: str
    source: str
    eventOccurrenceTime: datetime
    eventType: str
    relatedResources: List[ResourceTypeDef]
    eventOriginRegion: NotRequired[str]


class ManagedNotificationChildEventSummaryTypeDef(TypedDict):
    schemaVersion: Literal["v1.0"]
    sourceEventMetadata: ManagedSourceEventMetadataSummaryTypeDef
    messageComponents: MessageComponentsSummaryTypeDef
    aggregationDetail: AggregationDetailTypeDef
    eventStatus: EventStatusType
    notificationType: NotificationTypeType


class ListEventRulesResponseTypeDef(TypedDict):
    eventRules: List[EventRuleStructureTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]


class ListNotificationHubsResponseTypeDef(TypedDict):
    notificationHubs: List[NotificationHubOverviewTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]


ManagedNotificationChildEventTypeDef = TypedDict(
    "ManagedNotificationChildEventTypeDef",
    {
        "schemaVersion": Literal["v1.0"],
        "id": str,
        "messageComponents": MessageComponentsTypeDef,
        "notificationType": NotificationTypeType,
        "aggregateManagedNotificationEventArn": str,
        "textParts": Dict[str, TextPartValueTypeDef],
        "sourceEventDetailUrl": NotRequired[str],
        "sourceEventDetailUrlDisplayText": NotRequired[str],
        "eventStatus": NotRequired[EventStatusType],
        "startTime": NotRequired[datetime],
        "endTime": NotRequired[datetime],
        "organizationalUnitId": NotRequired[str],
        "aggregationDetail": NotRequired[AggregationDetailTypeDef],
    },
)
ManagedNotificationEventTypeDef = TypedDict(
    "ManagedNotificationEventTypeDef",
    {
        "schemaVersion": Literal["v1.0"],
        "id": str,
        "messageComponents": MessageComponentsTypeDef,
        "notificationType": NotificationTypeType,
        "textParts": Dict[str, TextPartValueTypeDef],
        "sourceEventDetailUrl": NotRequired[str],
        "sourceEventDetailUrlDisplayText": NotRequired[str],
        "eventStatus": NotRequired[EventStatusType],
        "aggregationEventType": NotRequired[AggregationEventTypeType],
        "aggregationSummary": NotRequired[AggregationSummaryTypeDef],
        "startTime": NotRequired[datetime],
        "endTime": NotRequired[datetime],
        "organizationalUnitId": NotRequired[str],
    },
)


class ManagedNotificationEventOverviewTypeDef(TypedDict):
    arn: str
    managedNotificationConfigurationArn: str
    relatedAccount: str
    creationTime: datetime
    notificationEvent: ManagedNotificationEventSummaryTypeDef
    aggregationEventType: NotRequired[AggregationEventTypeType]
    organizationalUnitId: NotRequired[str]
    aggregationSummary: NotRequired[AggregationSummaryTypeDef]
    aggregatedNotificationRegions: NotRequired[List[str]]


class NotificationEventOverviewTypeDef(TypedDict):
    arn: str
    notificationConfigurationArn: str
    relatedAccount: str
    creationTime: datetime
    notificationEvent: NotificationEventSummaryTypeDef
    aggregationEventType: NotRequired[AggregationEventTypeType]
    aggregateNotificationEventArn: NotRequired[str]
    aggregationSummary: NotRequired[AggregationSummaryTypeDef]


NotificationEventTypeDef = TypedDict(
    "NotificationEventTypeDef",
    {
        "schemaVersion": Literal["v1.0"],
        "id": str,
        "sourceEventMetadata": SourceEventMetadataTypeDef,
        "messageComponents": MessageComponentsTypeDef,
        "notificationType": NotificationTypeType,
        "textParts": Dict[str, TextPartValueTypeDef],
        "media": List[MediaElementTypeDef],
        "sourceEventDetailUrl": NotRequired[str],
        "sourceEventDetailUrlDisplayText": NotRequired[str],
        "eventStatus": NotRequired[EventStatusType],
        "aggregationEventType": NotRequired[AggregationEventTypeType],
        "aggregateNotificationEventArn": NotRequired[str],
        "aggregationSummary": NotRequired[AggregationSummaryTypeDef],
        "startTime": NotRequired[datetime],
        "endTime": NotRequired[datetime],
    },
)


class ManagedNotificationChildEventOverviewTypeDef(TypedDict):
    arn: str
    managedNotificationConfigurationArn: str
    relatedAccount: str
    creationTime: datetime
    childEvent: ManagedNotificationChildEventSummaryTypeDef
    aggregateManagedNotificationEventArn: str
    organizationalUnitId: NotRequired[str]


class GetManagedNotificationChildEventResponseTypeDef(TypedDict):
    arn: str
    managedNotificationConfigurationArn: str
    creationTime: datetime
    content: ManagedNotificationChildEventTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class GetManagedNotificationEventResponseTypeDef(TypedDict):
    arn: str
    managedNotificationConfigurationArn: str
    creationTime: datetime
    content: ManagedNotificationEventTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ListManagedNotificationEventsResponseTypeDef(TypedDict):
    managedNotificationEvents: List[ManagedNotificationEventOverviewTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]


class ListNotificationEventsResponseTypeDef(TypedDict):
    notificationEvents: List[NotificationEventOverviewTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]


class GetNotificationEventResponseTypeDef(TypedDict):
    arn: str
    notificationConfigurationArn: str
    creationTime: datetime
    content: NotificationEventTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ListManagedNotificationChildEventsResponseTypeDef(TypedDict):
    managedNotificationChildEvents: List[ManagedNotificationChildEventOverviewTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]



"""
Type annotations for notifications service Client.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_notifications.client import UserNotificationsClient

    session = Session()
    client: UserNotificationsClient = session.client("notifications")
    ```
"""

from __future__ import annotations

import sys
from typing import Any, overload

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .paginator import (
    ListChannelsPaginator,
    ListEventRulesPaginator,
    ListManagedNotificationChannelAssociationsPaginator,
    ListManagedNotificationChildEventsPaginator,
    ListManagedNotificationConfigurationsPaginator,
    ListManagedNotificationEventsPaginator,
    ListNotificationConfigurationsPaginator,
    ListNotificationEventsPaginator,
    ListNotificationHubsPaginator,
)
from .type_defs import (
    AssociateChannelRequestTypeDef,
    AssociateManagedNotificationAccountContactRequestTypeDef,
    AssociateManagedNotificationAdditionalChannelRequestTypeDef,
    CreateEventRuleRequestTypeDef,
    CreateEventRuleResponseTypeDef,
    CreateNotificationConfigurationRequestTypeDef,
    CreateNotificationConfigurationResponseTypeDef,
    DeleteEventRuleRequestTypeDef,
    DeleteNotificationConfigurationRequestTypeDef,
    DeregisterNotificationHubRequestTypeDef,
    DeregisterNotificationHubResponseTypeDef,
    DisassociateChannelRequestTypeDef,
    DisassociateManagedNotificationAccountContactRequestTypeDef,
    DisassociateManagedNotificationAdditionalChannelRequestTypeDef,
    GetEventRuleRequestTypeDef,
    GetEventRuleResponseTypeDef,
    GetManagedNotificationChildEventRequestTypeDef,
    GetManagedNotificationChildEventResponseTypeDef,
    GetManagedNotificationConfigurationRequestTypeDef,
    GetManagedNotificationConfigurationResponseTypeDef,
    GetManagedNotificationEventRequestTypeDef,
    GetManagedNotificationEventResponseTypeDef,
    GetNotificationConfigurationRequestTypeDef,
    GetNotificationConfigurationResponseTypeDef,
    GetNotificationEventRequestTypeDef,
    GetNotificationEventResponseTypeDef,
    GetNotificationsAccessForOrganizationResponseTypeDef,
    ListChannelsRequestTypeDef,
    ListChannelsResponseTypeDef,
    ListEventRulesRequestTypeDef,
    ListEventRulesResponseTypeDef,
    ListManagedNotificationChannelAssociationsRequestTypeDef,
    ListManagedNotificationChannelAssociationsResponseTypeDef,
    ListManagedNotificationChildEventsRequestTypeDef,
    ListManagedNotificationChildEventsResponseTypeDef,
    ListManagedNotificationConfigurationsRequestTypeDef,
    ListManagedNotificationConfigurationsResponseTypeDef,
    ListManagedNotificationEventsRequestTypeDef,
    ListManagedNotificationEventsResponseTypeDef,
    ListNotificationConfigurationsRequestTypeDef,
    ListNotificationConfigurationsResponseTypeDef,
    ListNotificationEventsRequestTypeDef,
    ListNotificationEventsResponseTypeDef,
    ListNotificationHubsRequestTypeDef,
    ListNotificationHubsResponseTypeDef,
    ListTagsForResourceRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    RegisterNotificationHubRequestTypeDef,
    RegisterNotificationHubResponseTypeDef,
    TagResourceRequestTypeDef,
    UntagResourceRequestTypeDef,
    UpdateEventRuleRequestTypeDef,
    UpdateEventRuleResponseTypeDef,
    UpdateNotificationConfigurationRequestTypeDef,
    UpdateNotificationConfigurationResponseTypeDef,
)

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import type as Type
    from collections.abc import Mapping
else:
    from typing import Dict, Mapping, Type
if sys.version_info >= (3, 12):
    from typing import Literal, Unpack
else:
    from typing_extensions import Literal, Unpack


__all__ = ("UserNotificationsClient",)


class Exceptions(BaseClientExceptions):
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ServiceQuotaExceededException: Type[BotocoreClientError]
    ThrottlingException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]


class UserNotificationsClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications.html#UserNotifications.Client)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        UserNotificationsClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications.html#UserNotifications.Client)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/can_paginate.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/generate_presigned_url.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#generate_presigned_url)
        """

    def associate_channel(self, **kwargs: Unpack[AssociateChannelRequestTypeDef]) -> Dict[str, Any]:
        """
        Associates a delivery <a
        href="https://docs.aws.amazon.com/notifications/latest/userguide/managing-delivery-channels.html">Channel</a>
        with a particular <code>NotificationConfiguration</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/associate_channel.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#associate_channel)
        """

    def associate_managed_notification_account_contact(
        self, **kwargs: Unpack[AssociateManagedNotificationAccountContactRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Associates an Account Contact with a particular
        <code>ManagedNotificationConfiguration</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/associate_managed_notification_account_contact.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#associate_managed_notification_account_contact)
        """

    def associate_managed_notification_additional_channel(
        self, **kwargs: Unpack[AssociateManagedNotificationAdditionalChannelRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Associates an additional Channel with a particular
        <code>ManagedNotificationConfiguration</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/associate_managed_notification_additional_channel.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#associate_managed_notification_additional_channel)
        """

    def create_event_rule(
        self, **kwargs: Unpack[CreateEventRuleRequestTypeDef]
    ) -> CreateEventRuleResponseTypeDef:
        """
        Creates an <a
        href="https://docs.aws.amazon.com/notifications/latest/userguide/glossary.html">
        <code>EventRule</code> </a> that is associated with a specified
        <code>NotificationConfiguration</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/create_event_rule.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#create_event_rule)
        """

    def create_notification_configuration(
        self, **kwargs: Unpack[CreateNotificationConfigurationRequestTypeDef]
    ) -> CreateNotificationConfigurationResponseTypeDef:
        """
        Creates a new <code>NotificationConfiguration</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/create_notification_configuration.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#create_notification_configuration)
        """

    def delete_event_rule(self, **kwargs: Unpack[DeleteEventRuleRequestTypeDef]) -> Dict[str, Any]:
        """
        Deletes an <code>EventRule</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/delete_event_rule.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#delete_event_rule)
        """

    def delete_notification_configuration(
        self, **kwargs: Unpack[DeleteNotificationConfigurationRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Deletes a <code>NotificationConfiguration</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/delete_notification_configuration.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#delete_notification_configuration)
        """

    def deregister_notification_hub(
        self, **kwargs: Unpack[DeregisterNotificationHubRequestTypeDef]
    ) -> DeregisterNotificationHubResponseTypeDef:
        """
        Deregisters a <code>NotificationConfiguration</code> in the specified Region.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/deregister_notification_hub.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#deregister_notification_hub)
        """

    def disable_notifications_access_for_organization(self) -> Dict[str, Any]:
        """
        Disables service trust between User Notifications and Amazon Web Services
        Organizations.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/disable_notifications_access_for_organization.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#disable_notifications_access_for_organization)
        """

    def disassociate_channel(
        self, **kwargs: Unpack[DisassociateChannelRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Disassociates a Channel from a specified <code>NotificationConfiguration</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/disassociate_channel.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#disassociate_channel)
        """

    def disassociate_managed_notification_account_contact(
        self, **kwargs: Unpack[DisassociateManagedNotificationAccountContactRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Disassociates an Account Contact with a particular
        <code>ManagedNotificationConfiguration</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/disassociate_managed_notification_account_contact.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#disassociate_managed_notification_account_contact)
        """

    def disassociate_managed_notification_additional_channel(
        self, **kwargs: Unpack[DisassociateManagedNotificationAdditionalChannelRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Disassociates an additional Channel from a particular
        <code>ManagedNotificationConfiguration</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/disassociate_managed_notification_additional_channel.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#disassociate_managed_notification_additional_channel)
        """

    def enable_notifications_access_for_organization(self) -> Dict[str, Any]:
        """
        Enables service trust between User Notifications and Amazon Web Services
        Organizations.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/enable_notifications_access_for_organization.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#enable_notifications_access_for_organization)
        """

    def get_event_rule(
        self, **kwargs: Unpack[GetEventRuleRequestTypeDef]
    ) -> GetEventRuleResponseTypeDef:
        """
        Returns a specified <code>EventRule</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_event_rule.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_event_rule)
        """

    def get_managed_notification_child_event(
        self, **kwargs: Unpack[GetManagedNotificationChildEventRequestTypeDef]
    ) -> GetManagedNotificationChildEventResponseTypeDef:
        """
        Returns the child event of a specific given
        <code>ManagedNotificationEvent</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_managed_notification_child_event.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_managed_notification_child_event)
        """

    def get_managed_notification_configuration(
        self, **kwargs: Unpack[GetManagedNotificationConfigurationRequestTypeDef]
    ) -> GetManagedNotificationConfigurationResponseTypeDef:
        """
        Returns a specified <code>ManagedNotificationConfiguration</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_managed_notification_configuration.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_managed_notification_configuration)
        """

    def get_managed_notification_event(
        self, **kwargs: Unpack[GetManagedNotificationEventRequestTypeDef]
    ) -> GetManagedNotificationEventResponseTypeDef:
        """
        Returns a specified <code>ManagedNotificationEvent</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_managed_notification_event.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_managed_notification_event)
        """

    def get_notification_configuration(
        self, **kwargs: Unpack[GetNotificationConfigurationRequestTypeDef]
    ) -> GetNotificationConfigurationResponseTypeDef:
        """
        Returns a specified <code>NotificationConfiguration</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_notification_configuration.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_notification_configuration)
        """

    def get_notification_event(
        self, **kwargs: Unpack[GetNotificationEventRequestTypeDef]
    ) -> GetNotificationEventResponseTypeDef:
        """
        Returns a specified <code>NotificationEvent</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_notification_event.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_notification_event)
        """

    def get_notifications_access_for_organization(
        self,
    ) -> GetNotificationsAccessForOrganizationResponseTypeDef:
        """
        Returns the AccessStatus of Service Trust Enablement for User Notifications and
        Amazon Web Services Organizations.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_notifications_access_for_organization.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_notifications_access_for_organization)
        """

    def list_channels(
        self, **kwargs: Unpack[ListChannelsRequestTypeDef]
    ) -> ListChannelsResponseTypeDef:
        """
        Returns a list of Channels for a <code>NotificationConfiguration</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/list_channels.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#list_channels)
        """

    def list_event_rules(
        self, **kwargs: Unpack[ListEventRulesRequestTypeDef]
    ) -> ListEventRulesResponseTypeDef:
        """
        Returns a list of <code>EventRules</code> according to specified filters, in
        reverse chronological order (newest first).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/list_event_rules.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#list_event_rules)
        """

    def list_managed_notification_channel_associations(
        self, **kwargs: Unpack[ListManagedNotificationChannelAssociationsRequestTypeDef]
    ) -> ListManagedNotificationChannelAssociationsResponseTypeDef:
        """
        Returns a list of Account contacts and Channels associated with a
        <code>ManagedNotificationConfiguration</code>, in paginated format.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/list_managed_notification_channel_associations.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#list_managed_notification_channel_associations)
        """

    def list_managed_notification_child_events(
        self, **kwargs: Unpack[ListManagedNotificationChildEventsRequestTypeDef]
    ) -> ListManagedNotificationChildEventsResponseTypeDef:
        """
        Returns a list of <code>ManagedNotificationChildEvents</code> for a specified
        aggregate <code>ManagedNotificationEvent</code>, ordered by creation time in
        reverse chronological order (newest first).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/list_managed_notification_child_events.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#list_managed_notification_child_events)
        """

    def list_managed_notification_configurations(
        self, **kwargs: Unpack[ListManagedNotificationConfigurationsRequestTypeDef]
    ) -> ListManagedNotificationConfigurationsResponseTypeDef:
        """
        Returns a list of Managed Notification Configurations according to specified
        filters, ordered by creation time in reverse chronological order (newest
        first).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/list_managed_notification_configurations.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#list_managed_notification_configurations)
        """

    def list_managed_notification_events(
        self, **kwargs: Unpack[ListManagedNotificationEventsRequestTypeDef]
    ) -> ListManagedNotificationEventsResponseTypeDef:
        """
        Returns a list of Managed Notification Events according to specified filters,
        ordered by creation time in reverse chronological order (newest first).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/list_managed_notification_events.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#list_managed_notification_events)
        """

    def list_notification_configurations(
        self, **kwargs: Unpack[ListNotificationConfigurationsRequestTypeDef]
    ) -> ListNotificationConfigurationsResponseTypeDef:
        """
        Returns a list of abbreviated <code>NotificationConfigurations</code> according
        to specified filters, in reverse chronological order (newest first).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/list_notification_configurations.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#list_notification_configurations)
        """

    def list_notification_events(
        self, **kwargs: Unpack[ListNotificationEventsRequestTypeDef]
    ) -> ListNotificationEventsResponseTypeDef:
        """
        Returns a list of <code>NotificationEvents</code> according to specified
        filters, in reverse chronological order (newest first).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/list_notification_events.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#list_notification_events)
        """

    def list_notification_hubs(
        self, **kwargs: Unpack[ListNotificationHubsRequestTypeDef]
    ) -> ListNotificationHubsResponseTypeDef:
        """
        Returns a list of <code>NotificationHubs</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/list_notification_hubs.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#list_notification_hubs)
        """

    def list_tags_for_resource(
        self, **kwargs: Unpack[ListTagsForResourceRequestTypeDef]
    ) -> ListTagsForResourceResponseTypeDef:
        """
        Returns a list of tags for a specified Amazon Resource Name (ARN).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/list_tags_for_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#list_tags_for_resource)
        """

    def register_notification_hub(
        self, **kwargs: Unpack[RegisterNotificationHubRequestTypeDef]
    ) -> RegisterNotificationHubResponseTypeDef:
        """
        Registers a <code>NotificationConfiguration</code> in the specified Region.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/register_notification_hub.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#register_notification_hub)
        """

    def tag_resource(self, **kwargs: Unpack[TagResourceRequestTypeDef]) -> Dict[str, Any]:
        """
        Tags the resource with a tag key and value.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/tag_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#tag_resource)
        """

    def untag_resource(self, **kwargs: Unpack[UntagResourceRequestTypeDef]) -> Dict[str, Any]:
        """
        Untags a resource with a specified Amazon Resource Name (ARN).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/untag_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#untag_resource)
        """

    def update_event_rule(
        self, **kwargs: Unpack[UpdateEventRuleRequestTypeDef]
    ) -> UpdateEventRuleResponseTypeDef:
        """
        Updates an existing <code>EventRule</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/update_event_rule.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#update_event_rule)
        """

    def update_notification_configuration(
        self, **kwargs: Unpack[UpdateNotificationConfigurationRequestTypeDef]
    ) -> UpdateNotificationConfigurationResponseTypeDef:
        """
        Updates a <code>NotificationConfiguration</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/update_notification_configuration.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#update_notification_configuration)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_channels"]
    ) -> ListChannelsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_event_rules"]
    ) -> ListEventRulesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_managed_notification_channel_associations"]
    ) -> ListManagedNotificationChannelAssociationsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_managed_notification_child_events"]
    ) -> ListManagedNotificationChildEventsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_managed_notification_configurations"]
    ) -> ListManagedNotificationConfigurationsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_managed_notification_events"]
    ) -> ListManagedNotificationEventsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_notification_configurations"]
    ) -> ListNotificationConfigurationsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_notification_events"]
    ) -> ListNotificationEventsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_notification_hubs"]
    ) -> ListNotificationHubsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/client/#get_paginator)
        """



"""
Type annotations for notifications service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_notifications.client import UserNotificationsClient
    from types_boto3_notifications.paginator import (
        ListChannelsPaginator,
        ListEventRulesPaginator,
        ListManagedNotificationChannelAssociationsPaginator,
        ListManagedNotificationChildEventsPaginator,
        ListManagedNotificationConfigurationsPaginator,
        ListManagedNotificationEventsPaginator,
        ListNotificationConfigurationsPaginator,
        ListNotificationEventsPaginator,
        ListNotificationHubsPaginator,
    )

    session = Session()
    client: UserNotificationsClient = session.client("notifications")

    list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
    list_event_rules_paginator: ListEventRulesPaginator = client.get_paginator("list_event_rules")
    list_managed_notification_channel_associations_paginator: ListManagedNotificationChannelAssociationsPaginator = client.get_paginator("list_managed_notification_channel_associations")
    list_managed_notification_child_events_paginator: ListManagedNotificationChildEventsPaginator = client.get_paginator("list_managed_notification_child_events")
    list_managed_notification_configurations_paginator: ListManagedNotificationConfigurationsPaginator = client.get_paginator("list_managed_notification_configurations")
    list_managed_notification_events_paginator: ListManagedNotificationEventsPaginator = client.get_paginator("list_managed_notification_events")
    list_notification_configurations_paginator: ListNotificationConfigurationsPaginator = client.get_paginator("list_notification_configurations")
    list_notification_events_paginator: ListNotificationEventsPaginator = client.get_paginator("list_notification_events")
    list_notification_hubs_paginator: ListNotificationHubsPaginator = client.get_paginator("list_notification_hubs")
    ```
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListChannelsRequestPaginateTypeDef,
    ListChannelsResponseTypeDef,
    ListEventRulesRequestPaginateTypeDef,
    ListEventRulesResponseTypeDef,
    ListManagedNotificationChannelAssociationsRequestPaginateTypeDef,
    ListManagedNotificationChannelAssociationsResponseTypeDef,
    ListManagedNotificationChildEventsRequestPaginateTypeDef,
    ListManagedNotificationChildEventsResponseTypeDef,
    ListManagedNotificationConfigurationsRequestPaginateTypeDef,
    ListManagedNotificationConfigurationsResponseTypeDef,
    ListManagedNotificationEventsRequestPaginateTypeDef,
    ListManagedNotificationEventsResponseTypeDef,
    ListNotificationConfigurationsRequestPaginateTypeDef,
    ListNotificationConfigurationsResponseTypeDef,
    ListNotificationEventsRequestPaginateTypeDef,
    ListNotificationEventsResponseTypeDef,
    ListNotificationHubsRequestPaginateTypeDef,
    ListNotificationHubsResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack

__all__ = (
    "ListChannelsPaginator",
    "ListEventRulesPaginator",
    "ListManagedNotificationChannelAssociationsPaginator",
    "ListManagedNotificationChildEventsPaginator",
    "ListManagedNotificationConfigurationsPaginator",
    "ListManagedNotificationEventsPaginator",
    "ListNotificationConfigurationsPaginator",
    "ListNotificationEventsPaginator",
    "ListNotificationHubsPaginator",
)

if TYPE_CHECKING:
    _ListChannelsPaginatorBase = Paginator[ListChannelsResponseTypeDef]
else:
    _ListChannelsPaginatorBase = Paginator  # type: ignore[assignment]

class ListChannelsPaginator(_ListChannelsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListChannels.html#UserNotifications.Paginator.ListChannels)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listchannelspaginator)
    """
    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListChannelsRequestPaginateTypeDef]
    ) -> PageIterator[ListChannelsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListChannels.html#UserNotifications.Paginator.ListChannels.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listchannelspaginator)
        """

if TYPE_CHECKING:
    _ListEventRulesPaginatorBase = Paginator[ListEventRulesResponseTypeDef]
else:
    _ListEventRulesPaginatorBase = Paginator  # type: ignore[assignment]

class ListEventRulesPaginator(_ListEventRulesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListEventRules.html#UserNotifications.Paginator.ListEventRules)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listeventrulespaginator)
    """
    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListEventRulesRequestPaginateTypeDef]
    ) -> PageIterator[ListEventRulesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListEventRules.html#UserNotifications.Paginator.ListEventRules.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listeventrulespaginator)
        """

if TYPE_CHECKING:
    _ListManagedNotificationChannelAssociationsPaginatorBase = Paginator[
        ListManagedNotificationChannelAssociationsResponseTypeDef
    ]
else:
    _ListManagedNotificationChannelAssociationsPaginatorBase = Paginator  # type: ignore[assignment]

class ListManagedNotificationChannelAssociationsPaginator(
    _ListManagedNotificationChannelAssociationsPaginatorBase
):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListManagedNotificationChannelAssociations.html#UserNotifications.Paginator.ListManagedNotificationChannelAssociations)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listmanagednotificationchannelassociationspaginator)
    """
    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListManagedNotificationChannelAssociationsRequestPaginateTypeDef]
    ) -> PageIterator[ListManagedNotificationChannelAssociationsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListManagedNotificationChannelAssociations.html#UserNotifications.Paginator.ListManagedNotificationChannelAssociations.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listmanagednotificationchannelassociationspaginator)
        """

if TYPE_CHECKING:
    _ListManagedNotificationChildEventsPaginatorBase = Paginator[
        ListManagedNotificationChildEventsResponseTypeDef
    ]
else:
    _ListManagedNotificationChildEventsPaginatorBase = Paginator  # type: ignore[assignment]

class ListManagedNotificationChildEventsPaginator(_ListManagedNotificationChildEventsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListManagedNotificationChildEvents.html#UserNotifications.Paginator.ListManagedNotificationChildEvents)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listmanagednotificationchildeventspaginator)
    """
    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListManagedNotificationChildEventsRequestPaginateTypeDef]
    ) -> PageIterator[ListManagedNotificationChildEventsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListManagedNotificationChildEvents.html#UserNotifications.Paginator.ListManagedNotificationChildEvents.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listmanagednotificationchildeventspaginator)
        """

if TYPE_CHECKING:
    _ListManagedNotificationConfigurationsPaginatorBase = Paginator[
        ListManagedNotificationConfigurationsResponseTypeDef
    ]
else:
    _ListManagedNotificationConfigurationsPaginatorBase = Paginator  # type: ignore[assignment]

class ListManagedNotificationConfigurationsPaginator(
    _ListManagedNotificationConfigurationsPaginatorBase
):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListManagedNotificationConfigurations.html#UserNotifications.Paginator.ListManagedNotificationConfigurations)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listmanagednotificationconfigurationspaginator)
    """
    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListManagedNotificationConfigurationsRequestPaginateTypeDef]
    ) -> PageIterator[ListManagedNotificationConfigurationsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListManagedNotificationConfigurations.html#UserNotifications.Paginator.ListManagedNotificationConfigurations.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listmanagednotificationconfigurationspaginator)
        """

if TYPE_CHECKING:
    _ListManagedNotificationEventsPaginatorBase = Paginator[
        ListManagedNotificationEventsResponseTypeDef
    ]
else:
    _ListManagedNotificationEventsPaginatorBase = Paginator  # type: ignore[assignment]

class ListManagedNotificationEventsPaginator(_ListManagedNotificationEventsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListManagedNotificationEvents.html#UserNotifications.Paginator.ListManagedNotificationEvents)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listmanagednotificationeventspaginator)
    """
    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListManagedNotificationEventsRequestPaginateTypeDef]
    ) -> PageIterator[ListManagedNotificationEventsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListManagedNotificationEvents.html#UserNotifications.Paginator.ListManagedNotificationEvents.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listmanagednotificationeventspaginator)
        """

if TYPE_CHECKING:
    _ListNotificationConfigurationsPaginatorBase = Paginator[
        ListNotificationConfigurationsResponseTypeDef
    ]
else:
    _ListNotificationConfigurationsPaginatorBase = Paginator  # type: ignore[assignment]

class ListNotificationConfigurationsPaginator(_ListNotificationConfigurationsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListNotificationConfigurations.html#UserNotifications.Paginator.ListNotificationConfigurations)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listnotificationconfigurationspaginator)
    """
    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListNotificationConfigurationsRequestPaginateTypeDef]
    ) -> PageIterator[ListNotificationConfigurationsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListNotificationConfigurations.html#UserNotifications.Paginator.ListNotificationConfigurations.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listnotificationconfigurationspaginator)
        """

if TYPE_CHECKING:
    _ListNotificationEventsPaginatorBase = Paginator[ListNotificationEventsResponseTypeDef]
else:
    _ListNotificationEventsPaginatorBase = Paginator  # type: ignore[assignment]

class ListNotificationEventsPaginator(_ListNotificationEventsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListNotificationEvents.html#UserNotifications.Paginator.ListNotificationEvents)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listnotificationeventspaginator)
    """
    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListNotificationEventsRequestPaginateTypeDef]
    ) -> PageIterator[ListNotificationEventsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListNotificationEvents.html#UserNotifications.Paginator.ListNotificationEvents.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listnotificationeventspaginator)
        """

if TYPE_CHECKING:
    _ListNotificationHubsPaginatorBase = Paginator[ListNotificationHubsResponseTypeDef]
else:
    _ListNotificationHubsPaginatorBase = Paginator  # type: ignore[assignment]

class ListNotificationHubsPaginator(_ListNotificationHubsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListNotificationHubs.html#UserNotifications.Paginator.ListNotificationHubs)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listnotificationhubspaginator)
    """
    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListNotificationHubsRequestPaginateTypeDef]
    ) -> PageIterator[ListNotificationHubsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications/paginator/ListNotificationHubs.html#UserNotifications.Paginator.ListNotificationHubs.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/paginators/#listnotificationhubspaginator)
        """



"""
Main interface for notifications service.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_notifications/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_notifications import (
        Client,
        ListChannelsPaginator,
        ListEventRulesPaginator,
        ListManagedNotificationChannelAssociationsPaginator,
        ListManagedNotificationChildEventsPaginator,
        ListManagedNotificationConfigurationsPaginator,
        ListManagedNotificationEventsPaginator,
        ListNotificationConfigurationsPaginator,
        ListNotificationEventsPaginator,
        ListNotificationHubsPaginator,
        UserNotificationsClient,
    )

    session = Session()
    client: UserNotificationsClient = session.client("notifications")

    list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
    list_event_rules_paginator: ListEventRulesPaginator = client.get_paginator("list_event_rules")
    list_managed_notification_channel_associations_paginator: ListManagedNotificationChannelAssociationsPaginator = client.get_paginator("list_managed_notification_channel_associations")
    list_managed_notification_child_events_paginator: ListManagedNotificationChildEventsPaginator = client.get_paginator("list_managed_notification_child_events")
    list_managed_notification_configurations_paginator: ListManagedNotificationConfigurationsPaginator = client.get_paginator("list_managed_notification_configurations")
    list_managed_notification_events_paginator: ListManagedNotificationEventsPaginator = client.get_paginator("list_managed_notification_events")
    list_notification_configurations_paginator: ListNotificationConfigurationsPaginator = client.get_paginator("list_notification_configurations")
    list_notification_events_paginator: ListNotificationEventsPaginator = client.get_paginator("list_notification_events")
    list_notification_hubs_paginator: ListNotificationHubsPaginator = client.get_paginator("list_notification_hubs")
    ```
"""

from .client import UserNotificationsClient
from .paginator import (
    ListChannelsPaginator,
    ListEventRulesPaginator,
    ListManagedNotificationChannelAssociationsPaginator,
    ListManagedNotificationChildEventsPaginator,
    ListManagedNotificationConfigurationsPaginator,
    ListManagedNotificationEventsPaginator,
    ListNotificationConfigurationsPaginator,
    ListNotificationEventsPaginator,
    ListNotificationHubsPaginator,
)

Client = UserNotificationsClient

__all__ = (
    "Client",
    "ListChannelsPaginator",
    "ListEventRulesPaginator",
    "ListManagedNotificationChannelAssociationsPaginator",
    "ListManagedNotificationChildEventsPaginator",
    "ListManagedNotificationConfigurationsPaginator",
    "ListManagedNotificationEventsPaginator",
    "ListNotificationConfigurationsPaginator",
    "ListNotificationEventsPaginator",
    "ListNotificationHubsPaginator",
    "UserNotificationsClient",
)
